@@ -39,6 +39,12 @@ define!({
         pub raw: JsWord,
     }
 
+    pub struct DashedIdent {
+        pub span: Span,
+        pub value: JsWord,
+        pub raw: JsWord,
+    }
+
     pub struct Str {
         pub span: Span,
         pub value: JsWord,
@@ -51,9 +57,14 @@ define!({
         pub raw: JsWord,
     }
 
+    pub enum DeclarationProperty {
+        Ident(Ident),
+        DashedIdent(DashedIdent),
+    }
+
     pub struct Declaration {
         pub span: Span,
-        pub property: Ident,
+        pub property: DeclarationProperty,
         pub value: Vec<Value>,
         pub important: Option<Span>,
     }
@@ -96,15 +107,15 @@ define!({
 
         Ident(Ident),
 
+        DashedIdent(DashedIdent),
+
         Str(Str),
 
         Function(Function),
 
         Bin(BinValue),
 
-        Space(SpaceValues),
-
-        Comma(CommaValues),
+        Delimiter(Delimiter),
 
         Tokens(Tokens),
 
@@ -113,14 +124,14 @@ define!({
         Url(Url),
     }
 
-    pub struct SpaceValues {
-        pub span: Span,
-        pub values: Vec<Value>,
+    pub enum DelimiterValue {
+        Comma,
+        Solidus,
     }
 
-    pub struct CommaValues {
+    pub struct Delimiter {
         pub span: Span,
-        pub values: Vec<Value>,
+        pub value: DelimiterValue,
     }
 
     pub struct BinValue {
@@ -339,6 +350,7 @@ define!({
         Namespace(NamespaceRule),
         Viewport(ViewportRule),
         Document(DocumentRule),
+        ColorProfile(ColorProfileRule),
         Unknown(UnknownAtRule),
     }
 
@@ -391,9 +403,14 @@ define!({
         pub block: Block,
     }
 
+    pub enum AtRuleName {
+        DashedIdent(DashedIdent),
+        Ident(Ident),
+    }
+
     pub struct UnknownAtRule {
         pub span: Span,
-        pub name: Ident,
+        pub name: AtRuleName,
         pub prelude: Vec<Value>,
         pub block: Option<SimpleBlock>,
     }
@@ -634,4 +651,15 @@ define!({
     pub enum SupportsFeature {
         Declaration(Declaration),
     }
+
+    pub enum ColorProfileName {
+        DashedIdent(DashedIdent),
+        Ident(Ident),
+    }
+
+    pub struct ColorProfileRule {
+        pub span: Span,
+        pub name: ColorProfileName,
+        pub block: Vec<DeclarationBlockItem>,
+    }
 });
